function [F t] = odesolver(f,dF,t,xo)
%[F t] = odesolver(f,dF,t,xo)
%
%odesolver solves a system of coupled differential equations using ode45.
%There are several differences between odesolver and ode45. It accepts an
%input function along with initial conditions, and returns solutions at
%times specified by the vector t. 
%
% Inputs:
%
%  f        :   An input function, specified using inline or passed with @.
%
%  dF       :   A system of differential equations, specified with inline
%               or passed with @. dF should have the following functional 
%               form:
%
%                   [df1 ... dfn] = dF(t,xo,f);
%
%  t        :   A time vector, t > 0. If t is a single number, the returned
%               value of t are the times evaluated by ode45.
%               
%  xo       :   A vector of initial conditions  for dF.
%
% Outputs:
%
%  F        :   F(k,:) is the kth system variable. plot(t,F(k,:)) shows
%               this output.
%
%  t        :   If the input t is vector, t is equal to the input t. If t
%               was passed as a single number, t is a vector of times that 
%               the system was evaluated at.

odeset('RelTol',1e-4);
trng = [0 t(end)];

options = odeset;
[ti Fi] = ode45(dF,trng,xo,options,f);
ti = ti';
Fi = Fi';

if(length(t) > 1)
    N = size(Fi,1);
    Nt = length(t);
    F = zeros(N,Nt);
    for k = 1:N
        F(k,:) = interp1(ti,Fi(k,:),t);
    end
else
    F = Fi;
    t = ti;
end
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%